==> huaweicloudsdkcbs-3.0.64-py2.py3-none-any.whl: huaweicloudsdkcbs/v1/model/execute_tb_session_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExecuteTbSessionResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'questions': 'list[ExecuteTbQuestion]'
    }

    attribute_map = {
        'questions': 'questions'
    }

    def __init__(self, questions=None):
        """ExecuteTbSessionResponse - a model defined in huaweicloud sdk"""
        
        super(ExecuteTbSessionResponse, self).__init__()

        self._questions = None
        self.discriminator = None

        if questions is not None:
            self.questions = questions

    @property
    def questions(self):
        """Gets the questions of this ExecuteTbSessionResponse.

        所有数据的信息。

        :return: The questions of this ExecuteTbSessionResponse.
        :rtype: list[ExecuteTbQuestion]
        """
        return self._questions

    @questions.setter
    def questions(self, questions):
        """Sets the questions of this ExecuteTbSessionResponse.

        所有数据的信息。

        :param questions: The questions of this ExecuteTbSessionResponse.
        :type: list[ExecuteTbQuestion]
        """
        self._questions = questions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecuteTbSessionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbs-3.0.95-py2.py3-none-any.whl: huaweicloudsdkcbs/v1/model/execute_tb_session_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExecuteTbSessionResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'questions': 'list[ExecuteTbQuestion]'
    }

    attribute_map = {
        'questions': 'questions'
    }

    def __init__(self, questions=None):
        """ExecuteTbSessionResponse

        The model defined in huaweicloud sdk

        :param questions: 所有数据的信息。
        :type questions: list[:class:`huaweicloudsdkcbs.v1.ExecuteTbQuestion`]
        """
        
        super(ExecuteTbSessionResponse, self).__init__()

        self._questions = None
        self.discriminator = None

        if questions is not None:
            self.questions = questions

    @property
    def questions(self):
        """Gets the questions of this ExecuteTbSessionResponse.

        所有数据的信息。

        :return: The questions of this ExecuteTbSessionResponse.
        :rtype: list[:class:`huaweicloudsdkcbs.v1.ExecuteTbQuestion`]
        """
        return self._questions

    @questions.setter
    def questions(self, questions):
        """Sets the questions of this ExecuteTbSessionResponse.

        所有数据的信息。

        :param questions: The questions of this ExecuteTbSessionResponse.
        :type questions: list[:class:`huaweicloudsdkcbs.v1.ExecuteTbQuestion`]
        """
        self._questions = questions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecuteTbSessionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
